This patch fixes a bug when renaming a new volume before the changes
are saved.  When the changes are saved after renaming the new volume,
Device Mapper returns errors because it can't rename a device that
doesn't exist yet.

--- evms-2.3.4/engine/volume.c	2004-05-24 16:34:12.000000000 -0500
+++ evms-2.3.4-fix/engine/volume.c	2004-06-17 10:37:10.000000000 -0500
@@ -1117,7 +1117,14 @@
 		}
 
 		if (rc == 0) {
-			rc = add_volume_to_rename_list(vol, new_name);
+			/*
+			 * If the volume is active, we must schedule
+			 * a rename with device-mapper.
+			 */
+			if (vol->flags & VOLFLAG_ACTIVE) {
+				rc = add_volume_to_rename_list(vol, new_name);
+			}
+
 			if (rc == 0) {
 				engine_unregister_name(vol->name);
 				engine_unregister_name(vol->name + EVMS_DEV_NODE_PATH_LEN);
